@@ -17,6 +17,7 @@ from collections import namedtuple
 import mock
 import yaml
 
+from tripleo_common.constants import PLAN_NAME_PATTERN
 from tripleo_common.tests import base
 from tripleo_common.utils import validations
 
@@ -88,6 +89,13 @@ VALIDATION_GROUPS_1_2_PARSED = {
 
 class ValidationsKeyTest(base.TestCase):
 
+    @mock.patch("oslo_concurrency.processutils.execute")
+    def test_create_ssh_keypair(self, mock_execute):
+        validations.create_ssh_keypair('/path/to/key')
+        mock_execute.assert_called_once_with(
+            '/usr/bin/ssh-keygen', '-t', 'rsa', '-N', '',
+            '-f', '/path/to/key', '-C', 'tripleo-validations')
+
     @mock.patch("oslo_concurrency.processutils.execute")
     @mock.patch('tempfile.mkstemp')
     def test_write_identity_file(self, mock_mkstemp, mock_execute):
@@ -201,3 +209,19 @@ class RunValidationTest(base.TestCase):
             'plan'
         )
         mock_find_validation.assert_called_once_with('validation')
+
+
+class RunPatternValidatorTest(base.TestCase):
+
+    def test_valid_patterns(self):
+        self.assertTrue(validations.pattern_validator("^$", ""))
+        self.assertTrue(
+            validations.pattern_validator(PLAN_NAME_PATTERN, "foo"))
+        self.assertTrue(
+            validations.pattern_validator(PLAN_NAME_PATTERN, "Foo-1"))
+
+    def test_invalid_patterns(self):
+        self.assertFalse(
+            validations.pattern_validator("^$", "foo"))
+        self.assertFalse(
+            validations.pattern_validator(PLAN_NAME_PATTERN, "foo_1"))
